@@ -1,4 +1,5 @@
-﻿###########################################################################
+﻿# -*- coding: utf-8 -*-
+###########################################################################
 ## All global variables in here are used all over the program
 ###########################################################################
 
@@ -54,7 +55,7 @@ Trigger=14 #Trigger level for movement
 maxTrigger=100
 
 demo=0
-debug=0
+debug=False
 
 RecordFilename=""
 RecordFile=""
@@ -83,7 +84,7 @@ PreviousMode="normal"
 SilentProfile=False
 PreviouseProfile="silent"
 
-language=""
+language="" #2-letter country code
 
 UIStyle=""
 
@@ -130,7 +131,10 @@ GraphBackground="#000000"
 #GraphBackground="#101010"
 #some colors are also defined in functions_record.py
 
+noiseReduction=4 #Smoothing of derivation data
+
 FilterScale=40
 limitMovement=250
 
+
 Animation=0
