@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 import sys
 import os
 import random
@@ -80,7 +82,7 @@ def DeleteAlarm():
             records.AlarmTime_seconds=-1
             records.AlarmTime_tuple=-1
     else:
-        if(data.debug==1): print "* No alarm to be deleted"
+        if(data.debug==True): print "* No alarm to be deleted"
 
 #    records.AlarmIsSet=False
     data.AlarmIsActive=False
@@ -122,4 +124,3 @@ def ProcessAlarm():
 #    print "data.AlarmIsActive:",  data.AlarmIsActive
 #    print ""
 
-
