@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 import sys
 import os
 import random
@@ -41,9 +43,9 @@ def ReadAccSensor():
         coords[1]=coords[1] / data.Sample_smoothing
         coords[2]=coords[2] / data.Sample_smoothing
     else: #dmo mode, use randomizer
-        coords[0]=int(random.uniform(-50,50))
-        coords[1]=int(random.uniform(-50,50))
-        coords[2]=int(random.uniform(-50,50))
+        coords[0]=int(random.uniform(-20,20))
+        coords[1]=int(random.uniform(-20,20))
+        coords[2]=int(random.uniform(-20,20))
     return coords
 
 
@@ -105,12 +107,14 @@ def GetFirstEntry():
 ##  Process the data, generate movement indication
 ###########################################################################
 def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
-    if(data.debug==1): print "Process Data (Process whole array:", ProcessAll,  ")"
+    if(data.debug==True): print "Process Data (Process whole array:", ProcessAll,  ")"
     data.Progress="Process data..."
     lastmovebeforegraph=0
     if(ProcessAll==True): start=0 #process whole array
     else: start=records.Index-data.Derivation-1 #process only last (changed) records
-    if(data.debug==1): print "Process entry", start+data.Derivation, "to", records.Index
+    if(data.debug==True): print "Process entry", start+data.Derivation, "to", records.Index
+
+
 
     for i in range(start, records.Index-data.Derivation):
         t=i*(records.Sampling_interval*records.Value_smoothing)/1000
@@ -127,7 +131,13 @@ def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
 #        records.arrData[4][i]=min(XYZderivation*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
         records.arrData[4][i]=abs(XYZderivation-data.derivation_offset)
 
-
+    #noise reduction of derivation
+    for i in range(data.noiseReduction,  records.Index-data.Derivation):
+#        val=0
+#        for j in range(0, data.noiseReduction):
+#            val+=records.arrData[4][i-j]
+#        records.arrData[5][i]  = val/data.noiseReduction
+        records.arrData[5][i]  = records.arrData[4][i]
 
 
 
@@ -155,32 +165,11 @@ def FilterData():
 ###########################################################################
 def DrawGraph(self,  QtGui, ShowFiltered=False):
     try:
-        if(data.debug==1): print "Draw Graph into bitmap"
+        if(data.debug==True): print "Draw Graph into bitmap"
 
         Xscale=data.arrXscale[data.Xscale]
         decade=360/Xscale
 
-    #    data.GraphStart=0
-
-    #    GraphSize=max(data.GraphBitMapLen+2, 785)
-
-    #        print "-----------------------------------"
-    #        print "Xscale:",  Xscale
-    #        print "Current index:",  records.Index
-    #        print "LastIndex:",  records.LastIndex
-    #        print "data.GraphBitMapLen (WindowSize):",  data.data.GraphBitMapLen
-    #        print "GraphStart:",  data.GraphStart
-    #        print "GraphEnd:",  data.GraphEnd
-    #        print "The area between index",data.GraphStart , "and",data.GraphEnd , "will be shown"
-    #        print "Scrollbar:",  ScrollbarStartPercent, "...", ScrollbarEndPercent, "%"
-
-    #        print "Shown graph is from index",  data.GraphStart,  "to",  data.GraphStart+data.GraphBitMapLen
-
-    #    PrintRecordData()
-
-    #    print "data.QuickMode:",  data.QuickMode
-
-    #    data.ChangesInGraph=False
         paint = QtGui.QPainter()
         paint.begin(self)
 
@@ -191,13 +180,6 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         paint.setBrush(QtGui.QColor(data.GraphBackground))
         paint.drawRect(0,0,records.MaxArrayDataLen+10,data.GraphBitMapHeight)
 
-
-    #    #show Graph border
-    ##    paint.setPen(QtGui.QColor("white"))
-    ##    paint.setBrush(QtGui.QColor("#101010"))
-    ###    paint.drawRect(0,0,781,data.Ysize)
-    ##    paint.drawRect(0,0,data.GraphBitMapLen,data.Ysize)
-
         #Stop if data is not ok
         if(records.statusID!="OK"):#Show useful infos
             paint.setFont(QtGui.QFont('Decorative', 20))
@@ -206,9 +188,8 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             return
 
 
-    #    GraphStart_tuple=Index2Tuple(data.GraphStart)
         GraphStart_tuple=Index2Tuple(0) #time of first record entry
-    #    if(data.debug==1): print "data.GraphStart",  data.GraphStart,  GraphStart_tuple
+    #    if(data.debug==True): print "data.GraphStart",  data.GraphStart,  GraphStart_tuple
         h=int(strftime("%H", GraphStart_tuple))
         m=int(strftime("%M", GraphStart_tuple))
         s=int(strftime("%S", GraphStart_tuple))
@@ -224,10 +205,6 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         s0=0# int(strftime("%S", LastFullHour_tuple))
 
 
-#        print GraphStart_seconds,  LastFullHour_sec,  secondsincefullhour
-#        print GraphStart_tuple,  LastFullHour_tuple
-#        print h0,  m0,  s0
-
         LastFullHour_index=Tuple2Index(LastFullHour_tuple)
 
         GraphStart_index=Tuple2Index(GraphStart_tuple)
@@ -236,10 +213,6 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         OffsetToLastFullHour=-1*(GraphStart_index - LastFullHour_index)/Xscale
         OffsetToLastFullHour=OffsetToLastFullHour- data.Derivation/Xscale  #Derivation takes 5 indices, so visualisation is delayed!
 
-    #    print "OffsetToLastFullHour:",  OffsetToLastFullHour,  "GraphStart_index:",  GraphStart_index,  "LastFullHour_index:",  LastFullHour_index
-
-    #    print "Last data is on:",  Index2Tuple(records.Index)
-
 
 
 
@@ -361,7 +334,7 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
 
-        #DRAW graph
+        #DRAW movement bars (yellow)
         paint.setPen(QtGui.QColor(data.MovementBarColor))
         peak=0
     #    for p in range(GraphStart_index,  records.Index-data.Derivation,  Xscale):
@@ -372,7 +345,8 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             #Too not miss any movement, we use the biggest movement of the merged records:
             peak=0
             for j in range(0, Xscale):
-                if(records.arrData[4][p+j]>peak): peak=records.arrData[4][p+j]
+#                if(records.arrData[4][p+j]>peak): peak=records.arrData[4][p+j]
+                if(records.arrData[5][p+j]>peak): peak=records.arrData[5][p+j]
             x=i/Xscale
     #        x=i/Xscale+1
     #        paint.drawLine(x, data.Ysize-peak-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
@@ -390,10 +364,12 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
 
-        #DRAW sleep graph
+        #DRAW sleep graph (blue)
         if(ShowFiltered==True):  #only show in view window, not during recording
             pen=QtGui.QPen()
 
+            records.arrData[6][records.Index-data.Derivation-Xscale]=records.arrData[6][records.Index-data.Derivation-Xscale-1] #fix for last entry
+
             #filling
             pen.setColor(QtGui.QColor(19, 54, 255, 150))
             pen.setWidth(1)
@@ -524,7 +500,7 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         #beep in test mode
         if(peak>data.Trigger): #if last value is over peak
             if(data.QuickMode==True and (records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
-                if(data.debug==1): print "Beep"
+                if(data.debug==True): print "Beep"
                 data.last_beep=records.Index
                 if(data.demo==False): #make beep for testing movement
                     b = os.popen("pacat --channels=2 /usr/share/sounds/ui-default_beep.wav")
@@ -570,16 +546,6 @@ def DrawStatistic(self,  QtGui, QtCore):
 
 
 
-
-
-
-
-
-
-
-
-
-
 #    paint.setBrush(QtGui.QGradient())
 
     paint.setPen(QtGui.QColor(data.GraphBackground))
@@ -642,7 +608,7 @@ def GenerateStatisticData():
     for i in range(0, 4): #clear array
         for j in range(0,  4): records.arrStatData[j][i]=0
 
-#    if(data.debug==1): print "Statistic data:",  records.arrStatData
+#    if(data.debug==True): print "Statistic data:",  records.arrStatData
 
     Xscale=data.arrXscale[data.Xscale]
 #    EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
@@ -717,7 +683,7 @@ def GenerateStatisticData():
 
 
 
-    if(data.debug==1): print "Statistic data:",  records.arrStatData
+    if(data.debug==True): print "Statistic data:",  records.arrStatData
 
 #    t_total=(records.EndTime_seconds-records.StartTime_seconds)/60
 #    if(t_total==0):  t_total=1
@@ -762,10 +728,10 @@ def InitRecord():
     records.statusID=""
 
     for i in range(0, records.MaxArrayDataLen-1): #clear data of old records
-        for j in range(0,  4):
+        for j in range(0,  6):
             records.arrData[j][i]=0
-        records.arrData[6][i]=0
-        records.arrData[5][i]=""
+#        records.arrData[6][i]=0
+#        records.arrData[5][i]=""
 
     print "Reset/cleared all record data"
 
@@ -808,6 +774,6 @@ def PrintRecordData(ShowArray=True):
 
     if(ShowArray==True):
         for i in range(0, records.Index): #print data of  records
-            print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i]
+            print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i],  records.arrData[6][i]
 
     print "##########################################################"
