@@ -1,4 +1,5 @@
 #!/usr/bin/env python2.5
+# -*- coding: utf-8 -*-
 ###########################################################################
 ## Name: 	       SleepAnalyser
 ## Description:   Sleep Analyser records your movement during your sleep. It is able to visualise it on a graph to show
@@ -14,7 +15,7 @@
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
-import os
+import os, sys
 
 import dbus
 from dbus.mainloop.qt import DBusQtMainLoop
@@ -22,15 +23,53 @@ from dbus.mainloop.qt import DBusQtMainLoop
 import data #own data
 import records #record data
 
-#app path has to be set before  first use!
+
+## INIT ###################################
+#app path has to be set first
 data.app_path=os.path.dirname(__file__)
 if(data.app_path==""): data.app_path="./"
 else: data.app_path=data.app_path+"/"
 
+print "SleepAnalyser"
+
+#Load version file
+try:
+    file = open(data.app_path+"version", 'r')
+    data.version = file.readline()
+    data.version=data.version[:-1]
+    data.build = file.readline()
+    print "Version: "+str(data.version)+ "-"+str(data.build)
+except:
+    print "Version file not found, please check your installation!"
+
+#check parameters
+if(len(sys.argv)>1):  #at least one parameter
+    if(sys.argv[1]=="debug"):
+        print "Enable Debug mode"
+        data.debug=True
+    elif(sys.argv[1]=="lang"):
+        if(len(sys.argv)>2):
+            data.language=sys.argv[2]
+            print "Set language to:", data.language
+        else:
+            print "Wrong parameter list"
+            print "Please set 2-letter language code"
+            exit()
+
+    else: #show command line interface data
+        print "sleepanalyser [options]"
+        print "OPTIONS:"
+        print "  debug: Shows debug information"
+        print "  lang COUNTRYCODE: Use specific language file. (Use 2-letter country code like de, en, fr, nl, ..."
+        exit()
+
+
 #load language file
 import i18n
 _ = i18n.language.gettext
 
+########################################
+
 #own functions
 from functions_general import *
 from functions_file import *
@@ -65,13 +104,6 @@ def main():
     global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow,  DateWindow,  AlarmTimeWindow,  AskForKeepWindow,  AdditionalInfoWindow,  HelpWindow
     global config
 
-    try:
-        if(sys.argv[1]=="debug"):
-            print "Enable Debug mode"
-            data.debug=1
-    except:
-        data.debug=0
-
     #if not on the N900, a acceleration sensor has to be simulated
     if(os.path.exists("/sys/class/i2c-adapter/i2c-3/3-001d/coord")): data.demo=False	#runs on real N900 hardware
     else: data.demo=True	#runs on other hardware/OS
@@ -79,6 +111,7 @@ def main():
 
     app = QApplication(sys.argv)
 
+    if(data.debug==True): print "Application path:",  data.app_path
 
     if(data.demo==True):
         print "Runs not on a N900 => Use randomizer for acceleration sensor data"
@@ -89,19 +122,6 @@ def main():
 
     config=LoadConfig()
 
-    #Load version file
-    try:
-        if(data.debug==1): print "Application path:",  data.app_path
-        file = open(data.app_path+"version", 'r')
-        data.version = file.readline()
-        data.version=data.version[:-1]
-        data.build = file.readline()
-        print "Application version: "+str(data.version)+ "-"+str(data.build)
-    except:
-        print "Version file not found, please check your installation!"
-
-
-
 
 
     #chek if module is available and could get loaded
@@ -231,8 +251,10 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 #        data.GraphStart=max(GraphLen-779, 0)
 
         data.ScrollToEnd=True
-        if(data.DisplayIsOn==True):
+        if(data.DisplayIsOn==True): #when display is on, update graph
             GenerateStatisticData()
+#            FilterData()
+#            GenerateGraphBitmap(RecordWindow, True)
             GenerateGraphBitmap(RecordWindow, False)
 
         if(records.Index==records.MaxArrayDataLen-1):
@@ -246,12 +268,12 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 
     ProcessAlarm()
 
-    if(data.DisplayIsOn==True):
+    if(data.DisplayIsOn==True):#when display is on, update clock animation
         RecordWindow.UpdateAnimation() #show turning clock
-        if(data.debug==1): print "-> o Update screen"
+        if(data.debug==True): print "-> o Update screen"
         RecordWindow.UpdateScreen()
     else:
-        if(data.debug==1): print "-> x Do not update screen, Display is off!"
+        if(data.debug==True): print "-> x Do not update screen, Display is off!"
 
 
 #    print data.AlarmIsActive,  data.StopAfterAlarm
@@ -305,7 +327,7 @@ def InitMeasurement():
     records.Trigger=data.Trigger #save Trigger level on start
     records.statusID=_("OK")
 
-    if(data.debug==1): PrintRecordData()
+    if(data.debug==True): PrintRecordData()
 
     #set scale and sampling interval
     if(data.QuickMode==False):
@@ -336,6 +358,7 @@ def InitMeasurement():
     WriteRecord()
 
     GenerateGraphBitmap(RecordWindow, False)
+    GenerateGraphBitmap(RecordWindow, True)
 #    RecordWindow.UpdateScreen()
 
     RecordWindow.ui.lblStatus.hide()
@@ -344,7 +367,7 @@ def InitMeasurement():
     app.processEvents() #force ui update
 
 
-    if(data.debug==1):
+    if(data.debug==True):
         print "Start timers (Interval:", data.interval ,"ms)..."
         print "Sampling interval:", data.interval, "ms"
         print "sample_smoothing:", data.Sample_smoothing, "x"
@@ -362,6 +385,7 @@ def StopMeasurement():
     global app
 
     GenerateStatisticData()
+#    GenerateGraphBitmap(RecordWindow, True)
     GenerateGraphBitmap(RecordWindow, False)
 
     RecordWindow.Canvas.update()
@@ -372,7 +396,7 @@ def StopMeasurement():
 
 #    print "Stop Measurement",  data.run
     if(data.run==True): #in recording
-        if(data.debug==1): print "Stop Timer"
+        if(data.debug==True): print "Stop Timer"
         app.timer_GetData.stop()
         StopRecordFile()
         UpdateFileHeader() #rewriterecord file (only do when recording is stopped!)
@@ -495,14 +519,11 @@ class frmStartWindow(QMainWindow):
 #        self.ui.lblNote.setText(_("Development version, might be unstable!"))
 
 
-
-
-
     ###########################################################################
     ## Show the collectring window (her the data gets visualised during the logging)
     ###########################################################################
     def StartMeasurementNormal(self): ##(Class StartWindow)
-        if(data.debug==1): print "Measure in normal Mode"
+        if(data.debug==True): print "Measure in normal Mode"
         data.QuickMode=False #run in normal mode
         self.StartMeasurement()
 
@@ -514,7 +535,7 @@ class frmStartWindow(QMainWindow):
     ## Show the collectring window (her the data gets visualised during the logging)
     ###########################################################################
     def StartMeasurementQuick(self): ##(Class StartWindow)
-        if(data.debug==1): print "Measure in QuickMode"
+        if(data.debug==True): print "Measure in QuickMode"
         data.QuickMode=True #run in quick mode (for testing only)
         data.Xscale=0 #default zoom level
         self.StartMeasurement()
@@ -720,10 +741,10 @@ class frmRecordWindow(QMainWindow):
 
     def UpdateScreen(self): ##(Class RecordWindow)
 #        if(data.DisplayIsOn==False):
-#            if(data.debug==1): print "-> x Do not update screen, Display is off!"
+#            if(data.debug==True): print "-> x Do not update screen, Display is off!"
 #            return
 #        else:
-#            if(data.debug==1): print "-> o Update screen"
+#            if(data.debug==True): print "-> o Update screen"
 
         if(data.run==True): #recording
             t=time.mktime(time.localtime())
@@ -774,6 +795,7 @@ class frmRecordWindow(QMainWindow):
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         Zoom(+1)
+#        GenerateGraphBitmap(self, True)
         GenerateGraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
@@ -784,6 +806,7 @@ class frmRecordWindow(QMainWindow):
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         Zoom(-1)
+#        GenerateGraphBitmap(self, True)
         GenerateGraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
@@ -798,6 +821,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
         else: self.ui.bRaiseTrigger.setEnabled(True)
 
+#        GenerateGraphBitmap(self, True)
         GenerateGraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
@@ -812,6 +836,7 @@ class frmRecordWindow(QMainWindow):
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
 
+#        GenerateGraphBitmap(self, True)
         GenerateGraphBitmap(self, False)
         self.ui.lblStatus.hide()
 
@@ -946,7 +971,8 @@ class frmViewWindow(QMainWindow):
 #        if(diff_sec>86400): d="1 day, " #longer than 24h
 #        else: d=""
 #        print day
-        self.ui.lblStart.setText(str(day))
+#        self.ui.lblStart.setText(str(day))
+        self.ui.lblStart.setText(QtGui.QApplication.translate("ViewWindow", day, None, QtGui.QApplication.UnicodeUTF8))
 #        self.ui.lblEnd.setText(str(d1)+" (Duration: "+d+str(diff)+")")
 #        self.ui.lblEnd.setText(_("Start:")+" "+d0+", "+_("End:")+" "+d1+", "+_("Duration:")+" "+diff)
 #        print d0+" - "+d1+"   ("+diff+")"
@@ -1021,14 +1047,12 @@ class frmViewWindow(QMainWindow):
             self.UpdateScreen()
             app.processEvents() #force ui update
 
-
         self.ui.lblStatus.setText(_("Processessing data..."))
         app.processEvents() #force ui update
         ProcessData(True, True)
 
         self.ui.lblStatus.setText(_("Rendering data..."))
         app.processEvents() #force ui update
-
         FilterData()
 
         self.ui.lblStatus.setText(_("Generating statistic..."))
@@ -1090,10 +1114,6 @@ class frmViewWindow(QMainWindow):
 
 
 
-
-
-
-
     ###########################################################################
     ##
     ###########################################################################
@@ -1214,7 +1234,7 @@ class frmViewWindow(QMainWindow):
     ###########################################################################
     def ShowFileDialog(self): ##(Class ViewWindow)
         data.RecordFolder=string.replace(data.RecordFolder, "~",  data.homedir) #workaround
-        if(data.debug==1): print "Open file dialog in:",  data.RecordFolder
+        if(data.debug==True): print "Open file dialog in:",  data.RecordFolder
         tmp= QFileDialog.getOpenFileName(None,_("Open SleepAnalyser record"), data.RecordFolder, _("Record Files")+" (*.csv)")
         print "Selected file:",  tmp
         return tmp
@@ -1325,6 +1345,7 @@ class frmHelpWindow(QMainWindow):
         txt=""
         for line in file: txt=txt+line+"\n"
         file.close()
+        txt=QtGui.QApplication.translate("", txt, None, QtGui.QApplication.UnicodeUTF8)
         self.ui.textBrowser.setHtml(txt)
 
         self.setWindowTitle("SleepAnalyser ("+_("Help")+")")
@@ -1585,30 +1606,30 @@ class frmAdditionalInfoWindow(QMainWindow):
         shortfolder=string.replace(data.RecordFolder, data.homedir, "~/")
         shortfolder=string.replace(shortfolder, "//", "/") #workaround
 
-        d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
+        d0=strftime("%A %d. %B %Y  %H:%M", records.StartTime_tuple)
 #        EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
 #        EndTime_tuple=Seconds2Tuple(records.EndTime_seconds)
         if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", records.EndTime_tuple)):
-            d1=strftime("%H:%M:%S", records.EndTime_tuple) #on same day, only show date once
+            d1=strftime("%H:%M", records.EndTime_tuple) #on same day, only show date once
         else:
-            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", records.EndTime_tuple)
+            d1=strftime("%a. %d.%m.%Y  %H:%M", records.EndTime_tuple)
 
         diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
 #        diff=time.strftime("%X", time.gmtime(diff_sec))
-        diff=time.strftime("%H:%M:%S", time.gmtime(diff_sec))
+        diff=time.strftime("%Hh %Mm", time.gmtime(diff_sec))
 
         if(diff_sec>86400): diff="1 day, "+diff #longer than 24h
 
         if(records.AlarmIsSet==True):
-            a0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowStart_tuple)
+            a0=strftime("%A %d. %B %Y  %H:%M", records.AlarmTimeWindowStart_tuple)
             if(strftime("%d.%m.%Y", records.AlarmTimeWindowStart_tuple)==strftime("%d.%m.%Y", records.AlarmTimeWindowEnd_tuple)):
-                a1=strftime("%H:%M:%S", records.AlarmTimeWindowEnd_tuple) #on same day, only show date once
+                a1=strftime("%H:%M", records.AlarmTimeWindowEnd_tuple) #on same day, only show date once
             else:
-                a1=strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowEnd_tuple)
-            alarm="<b>"+_("Alarm Time Window:")+"</b> "+a0+" - "+a1 + "<br>"
+                a1=strftime("%A %d. %B %Y  %H:%M", records.AlarmTimeWindowEnd_tuple)
+            alarm="<b>"+_("Alarm Time Window:")+"</b> "+QtGui.QApplication.translate("", a0, None, QtGui.QApplication.UnicodeUTF8)+" - "+QtGui.QApplication.translate("", a1, None, QtGui.QApplication.UnicodeUTF8) + "<br>"
             if(records.AlarmTime_seconds!=-1): #alarm was set
                 if(records.EndTime_seconds>=records.AlarmTime_seconds-60): #alarm got set off during recording (-60 is workaround)
-                    alarm=alarm+"<b>"+_("Alarm:")+"</b> "+_("Alarm went off on:")+" "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)+"<br>"
+                    alarm=alarm+"<b>"+_("Alarm:")+"</b> "+_("Alarm went off on:")+" "+QtGui.QApplication.translate("", strftime("%A %d. %B %Y  %H:%M", records.AlarmTime_tuple), None, QtGui.QApplication.UnicodeUTF8)+"<br>"
                     if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
                         alarm=alarm+"<b>"+_("Alarm reason:")+"</b> "+_("End of alarm time window")+"<br>"
                     else:
@@ -1621,15 +1642,15 @@ class frmAdditionalInfoWindow(QMainWindow):
             alarm="<b>"+_("Alarm:")+"</b> "+_("No alarm was set")+"<br>"
 
         txt= "<b>"+_("File:")+"</b> "+str(shortfolder)+str(data.RecordFilename+"<br>") + \
-        "<b>"+_("Date/Time:")+"</b> "+d0+" - "+d1+"<br>" + \
+        "<b>"+_("Date/Time:")+"</b> "+QtGui.QApplication.translate("", d0, None, QtGui.QApplication.UnicodeUTF8)+" - "+d1+"<br>" + \
         "<b>"+_("Duration:")+"</b> "+ diff+"<br>" + \
+        "<b>"+_("Note:")+"</b> "+QtGui.QApplication.translate("", records.Note, None, QtGui.QApplication.UnicodeUTF8)+"<br>" + \
+        "<b>"+_("User:")+"</b> "+QtGui.QApplication.translate("", records.User, None, QtGui.QApplication.UnicodeUTF8) +"<br>" + \
         "<b>"+_("Record entries:")+"</b> "+str(records.Index)+" (1/"+str(int(records.Sampling_interval*records.Value_smoothing/1000))+" "+_("seconds")+")<br>" +\
         "<b>"+_("Record version:")+"</b> "+str(records.SWversion) + "<br>" + \
         alarm +\
         "<b>"+_("Trigger level:")+"</b> "+str(records.Trigger) + "<br>" + \
-        "<b>"+_("Condition of record:")+"</b> "+str(records.status)
-#        "<b>"+_("User:")+"</b> "+str(records.User) +"<br>" + \ ##Disabled due charset errors
-#        "<b>"+_("Note:")+"</b> "+str(records.Note)+"<br>" +\ ##Disabled due charset errors
+        "<b>"+_("Condition of record:")+"</b> "+str(records.status) + "<br>"
 
 
 
@@ -1643,12 +1664,12 @@ class frmAdditionalInfoWindow(QMainWindow):
 #        pl=100-pa-pb-pc
 
         txt=txt+"<hr>"
-        txt=txt+"<b>"+_("Statistics:")+"</b><table>\n" + \
+        txt=txt+"<b>"+_("Statistics:")+"</b><table CELLPADDING=2>\n" + \
                 "<tr bgcolor=#DCDCDC><td><b>"+_("Time without<br>movement:")+" </b></td>   <td><b>"+_("Total:")+" </b></td>                                     <td><b>"+_("Maximum:")+"</b></td>                                    <td><b>"+_("Count:")+" </b></td>                     <td colspan=2><b>"+_("Time percent:")+"</b></td>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+"&gt; 7 "+_("minutes:")+"</b></td>         <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 7 "+_("minutes:")+"</b></td>         <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 15 "+_("minutes:")+"</b></td>        <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 30 "+_("minutes:")+"</b></td>        <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+"&gt; 7 "+_("minutes:")+"</b></td>         <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[3][0]))+"</nobr></td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 7 "+_("minutes:")+"</b></td>         <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[2][0]))+"</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[2][2]))+"</nobr></td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 15 "+_("minutes:")+"</b></td>        <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[1][0]))+"</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[1][2]))+"</nobr></td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+"&lt; 30 "+_("minutes:")+"</b></td>        <td><nobr>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[0][0]))+"</nobr></td>    <td><nobr>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[0][2]))+"</nobr></td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
               "</table>\n"
 
         txt=txt+"<hr>"
@@ -1710,7 +1731,7 @@ class frmAlarmTimeWindow(QMainWindow):
         if(data.AlarmHour==-1 or data.AlarmMinute==-1):
             data.AlarmHour=7
             data.AlarmMinute=0
-        if(data.debug==1): print "Alarm time:",  data.AlarmHour, ":",  data.AlarmMinute
+        if(data.debug==True): print "Alarm time:",  data.AlarmHour, ":",  data.AlarmMinute
         self.ui.lstAlarmHour.setCurrentRow(int(data.AlarmHour))
         self.ui.lstAlarmMinute.setCurrentRow(int(data.AlarmMinute)/5)
         self.ui.lstAlarmTimeWindow.setCurrentRow(int(data.AlarmTimeWindow)/5-1)
@@ -1910,7 +1931,7 @@ class DisplayStatusDaemon:
                                         signal_name='display_status_ind',
                                         dbus_interface='com.nokia.mce.signal')
 
-            if(data.debug==1): print "DisplayStatusDaemon started"
+            if(data.debug==True): print "DisplayStatusDaemon started"
 
 
 
@@ -1930,7 +1951,7 @@ class DisplayStatusDaemon:
             data.DisplayIsOn=True
 #            if(data.run==True):
             if(RecordWindow.isHidden()==False):
-                if(data.debug==1): print "Update RecordWindow screen & graph"
+                if(data.debug==True): print "Update RecordWindow screen & graph"
 #                data.ChangesInGraph=True
 
                 GenerateStatisticData()
@@ -1961,10 +1982,10 @@ class MyGraphCanvas(QtGui.QWidget):
     ###########################################################################
     def paintEvent(self, event):
         if(data.DisplayIsOn==False):
-            if(data.debug==1): print "-> o Do not paint event (Graph), Display is off!"
+            if(data.debug==True): print "-> o Do not paint event (Graph), Display is off!"
             return
         else:
-            if(data.debug==1): print "-> x paint event (Graph)"
+            if(data.debug==True): print "-> x paint event (Graph)"
 
         paint = QtGui.QPainter()
         paint.begin(self)
@@ -1993,10 +2014,10 @@ class MyStatCanvas(QtGui.QWidget):
     ###########################################################################
     def paintEvent(self, event):
         if(data.DisplayIsOn==False):
-            if(data.debug==1): print "-> o Do not paint event (Statistics), Display is off!"
+            if(data.debug==True): print "-> o Do not paint event (Statistics), Display is off!"
             return
         else:
-            if(data.debug==1): print "-> x paint event (Statistics)"
+            if(data.debug==True): print "-> x paint event (Statistics)"
 
         paint = QtGui.QPainter()
         paint.begin(self)
@@ -2018,17 +2039,18 @@ class MyStatCanvas(QtGui.QWidget):
 ###########################################################################
 def GenerateGraphBitmap(self, ShowFiltered=False):
 #    if(data.DisplayIsOn==False):
-#        if(data.debug==1): print "-> o Do not Generate Graph Bitmap, Display is off!"
+#        if(data.debug==True): print "-> o Do not Generate Graph Bitmap, Display is off!"
 #        return
 #    else:
-    if(data.debug==1): print "Generate Graph Bitmap"
+    if(data.debug==True): print "Generate Graph Bitmap"
 
     Xscale=data.arrXscale[data.Xscale]
 #        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  770)
-    if(ShowFiltered==False): #recording
+    if(data.run==True): #recording
+#    if(ShowFiltered==False): #recording
         data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  735)
     else: #view window, show filtered graph
-        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  649) #628 minimum width
+        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  649) #628 minimum graph width
     data.GraphBitMapHeight=data.Ysize+34
 
 #    print "GraphBitMapLen:",  data.GraphBitMapLen,  ", GraphBitMapHeight:",  data.GraphBitMapHeight ,  ", Ysize is:", data.Ysize
@@ -2060,10 +2082,10 @@ def GenerateGraphBitmap(self, ShowFiltered=False):
 ###########################################################################
 def GenerateStatisticsBitmap(self):
 #    if(data.DisplayIsOn==False):
-#        if(data.debug==1): print "-> o Do not Generate Statistics Bitmap, Display is off!"
+#        if(data.debug==True): print "-> o Do not Generate Statistics Bitmap, Display is off!"
 #        return
 #    else:
-    if(data.debug==1): print "Generate Statistics Bitmap"
+    if(data.debug==True): print "Generate Statistics Bitmap"
 
 #    try: #TESTING
     data.StatisticsBitMap = QtGui.QPixmap(data.StatisticsBitMapLen,  data.StatisticsBitMapHeight) #create bitmap for graph
